@@ -155,8 +155,8 @@ public class FormatData_ca extends ListResourceBundle {
                "4T",
             };
         final String[] metaValue_AmPmMarkers = new String[] {
-               "a. m.",
-               "p. m.",
+               "a.\u00a0m.",
+               "p.\u00a0m.",
             };
         final String[] metaValue_Eras = new String[] {
                "aC",
@@ -174,25 +174,25 @@ public class FormatData_ca extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "eB",
             };
         final String[] metaValue_java_time_japanese_DatePatterns = new String[] {
-               "EEEE d MMMM 'de' y G",
+               "EEEE, d MMMM 'de' y G",
                "d MMMM 'de' y G",
                "d/M/y G",
                "d/M/yy GGGGG",
             };
         final String[] metaValue_japanese_DatePatterns = new String[] {
-               "EEEE d MMMM 'de' y GGGG",
+               "EEEE, d MMMM 'de' y GGGG",
                "d MMMM 'de' y GGGG",
                "d/M/y GGGG",
                "d/M/yy G",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
-               "",
-               "AH",
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "Abans de ROC",
+               "ROC",
             };
         final String metaValue_calendarname_gregorian = "calendari gregori\u00e0";
         final Object[][] data = new Object[][] {
@@ -200,7 +200,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "field.year", "any" },
             { "calendarname.islamic-umalqura", "calendari isl\u00e0mic (Umm al-Qura)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_japanese_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -210,12 +210,7 @@ public class FormatData_ca extends ListResourceBundle {
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras",
-                new String[] {
-                    "Abans de ROC",
-                    "ROC",
-                }
-            },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "Hora est\u00e0ndard, {0}" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -262,12 +257,11 @@ public class FormatData_ca extends ListResourceBundle {
             { "field.minute", "minut" },
             { "field.era", "era" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "a. m./p. m." },
+            { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.roc", "calendari de la Rep\u00fablica de Xina" },
             { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
             { "field.month", "mes" },
             { "field.second", "segon" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
@@ -288,6 +282,7 @@ public class FormatData_ca extends ListResourceBundle {
                 }
             },
             { "calendarname.islamic", "calendari isl\u00e0mic" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
@@ -334,8 +329,9 @@ public class FormatData_ca extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "fus horari" },
@@ -350,9 +346,9 @@ public class FormatData_ca extends ListResourceBundle {
             { "field.weekday", "dia de la setmana" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
@@ -365,7 +361,7 @@ public class FormatData_ca extends ListResourceBundle {
                 }
             },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "setmana" },
             { "buddhist.DateTimePatterns",
                 new String[] {
@@ -404,19 +400,20 @@ public class FormatData_ca extends ListResourceBundle {
                     "0m",
                     "00m",
                     "000m",
-                    "0M",
+                    "0\u00a0M",
                     "00\u00a0M",
                     "000\u00a0M",
                     "0000\u00a0M",
                     "00mM",
                     "000mM",
-                    "0B",
+                    "0\u00a0B",
                     "00\u00a0B",
                     "000\u00a0B",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "Horari d\u2019estiu, {0}" },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "timezone.regionFormat.daylight", "Hora d\u2019estiu, {0}" },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d MMMM 'de' y",
@@ -430,7 +427,6 @@ public class FormatData_ca extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "hora" },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
             { "calendarname.buddhist", "calendari budista" },
             { "standalone.MonthNames",
                 new String[] {
