@@ -172,16 +172,6 @@ public class FormatData_tr extends ListResourceBundle {
                "M\u00d6",
                "MS",
             };
-        final String[] metaValue_TimePatterns = new String[] {
-               "HH:mm:ss zzzz",
-               "HH:mm:ss z",
-               "HH:mm:ss",
-               "HH:mm",
-            };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
-               "BC",
-               "BE",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "G d MMMM y EEEE",
                "G d MMMM y",
@@ -194,11 +184,15 @@ public class FormatData_tr extends ListResourceBundle {
                "GGGG d MMM y",
                "G d.MM.y",
             };
-        final String[] metaValue_roc_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "R.O.C. \u00d6ncesi",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
                "Before R.O.C.",
                "Minguo",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "Hicri",
             };
@@ -208,7 +202,6 @@ public class FormatData_tr extends ListResourceBundle {
             { "field.year", "y\u0131l" },
             { "calendarname.islamic-umalqura", "Hicri Takvim (\u00dcmm\u00fc-l Kurra Takvimi)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -223,14 +216,8 @@ public class FormatData_tr extends ListResourceBundle {
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "Arap Takvimi" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras",
-                new String[] {
-                    "R.O.C. \u00d6ncesi",
-                    "Minguo",
-                }
-            },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "{0} Standart Saati" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -238,6 +225,7 @@ public class FormatData_tr extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "Milattan \u00d6nce",
@@ -308,9 +296,9 @@ public class FormatData_tr extends ListResourceBundle {
             { "calendarname.roc", "\u00c7in Cumhuriyeti Takvimi" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "ay" },
-            { "roc.Eras", metaValue_roc_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "saniye" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -323,8 +311,9 @@ public class FormatData_tr extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Hicri Takvim" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "{0} Saati" },
             { "long.CompactNumberPatterns",
@@ -354,12 +343,11 @@ public class FormatData_tr extends ListResourceBundle {
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
-            { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "saat dilimi" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
@@ -372,7 +360,8 @@ public class FormatData_tr extends ListResourceBundle {
             { "field.weekday", "haftan\u0131n g\u00fcn\u00fc" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
@@ -380,7 +369,6 @@ public class FormatData_tr extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
             { "field.week", "hafta" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -419,7 +407,6 @@ public class FormatData_tr extends ListResourceBundle {
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "saat" },
@@ -440,13 +427,13 @@ public class FormatData_tr extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Budist Takvimi" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
-            { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
