@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,142 +71,7 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "ARS", "ARS" },
-            { "AWG", "AWG" },
-            { "AZN", "AZN" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BGN", "BGN" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CZK", "CZK" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ETB", "ETB" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "GEL", "GEL" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MKD", "MKD" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
-            { "MYR", "MYR" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PGK", "PGK" },
-            { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDG", "SDG" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJS", "TJS" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UGX", "UGX" },
             { "USD", "$" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEF", "VEF" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "YER", "YER" },
-            { "ZAR", "ZAR" },
-            { "ZMW", "ZMW" },
             { "aed", "\u13cc\u13ca \u13a2\u13f3\u13be\u13b5\u13cd\u13d4\u13c5 \u13a1\u13b3\u13c8 \u13a2\u13b9\u13b5\u13d8\u13cf \u13a0\u13d5\u13b3" },
             { "afn", "\u13a0\u13eb\u13a8\u13c2\u13cd\u13d6\u13c2 \u13a0\u13d5\u13b3" },
             { "all", "\u13a0\u13b5\u13c7\u13c2\u13ef \u13a0\u13d5\u13b3" },
@@ -217,7 +82,7 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
             { "aud", "\u13a1\u13b3\u13d7\u13dc \u13a0\u13d5\u13b3" },
             { "awg", "\u13a0\u13b7\u13c6 \u13a0\u13d5\u13b3" },
             { "azn", "\u13a0\u13cf\u13b5\u13c6\u13cc\u13c2 \u13a0\u13d5\u13b3" },
-            { "bam", "\u13c9\u13cf\u13c2\u13a0 \u13a0\u13b4 \u13b2\u13e4\u13aa\u13eb \u13a6\u13c1\u13df\u13f4\u13cd\u13d4\u13c5 \u13a0\u13d5\u13b3" },
+            { "bam", "\u13c9\u13cf\u13c2\u13a0-\u13b2\u13e4\u13aa\u13eb \u13a6\u13c1\u13df\u13f4\u13cd\u13d4\u13c5 \u13a0\u13d5\u13b3" },
             { "bbd", "\u13c6\u13c7\u13d9\u13cd \u13a0\u13d5\u13b3" },
             { "bdt", "\u13c6\u13c2\u13a6\u13b5\u13d5\u13cd \u13a0\u13d5\u13b3" },
             { "bgn", "\u13ca\u13b5\u13a8\u13b5\u13a0 \u13a0\u13d5\u13b3" },
@@ -288,7 +153,7 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
             { "kzt", "\u13a7\u13ce\u13a7\u13cd\u13d5\u13c2 \u13a0\u13d5\u13b3" },
             { "lak", "\u13b3\u13a3 \u13a0\u13d5\u13b3" },
             { "lbp", "\u13b4\u13c6\u13be\u13c2 \u13a0\u13d5\u13b3" },
-            { "lkr", "\u13cd\u13b5\u13b3\u13c2\u13a7 \u13a0\u13d5\u13b3" },
+            { "lkr", "\u13cd\u13b5 \u13b3\u13c2\u13a7 \u13a0\u13d5\u13b3" },
             { "lrd", "\u13b3\u13c8\u13b5\u13ef \u13a0\u13d5\u13b3" },
             { "lyd", "\u13b5\u13c8\u13ef \u13a0\u13d5\u13b3" },
             { "mad", "\u13bc\u13b6\u13aa \u13a0\u13d5\u13b3" },
@@ -298,8 +163,8 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
             { "mmk", "\u13b9\u13ef\u13b9\u13b5 \u13a0\u13d5\u13b3" },
             { "mnt", "\u13b9\u13c2\u13aa\u13b5\u13a0 \u13a0\u13d5\u13b3" },
             { "mop", "\u13b9\u13a7\u13a3 \u13a0\u13d5\u13b3" },
-            { "mro", "\u13bc\u13b5\u13cf\u13a5\u13cd \u13a0\u13d5\u13b3 (1973\u20132017)" },
-            { "mru", "\u13bc\u13b5\u13cf\u13a5\u13cd \u13a0\u13d5\u13b3" },
+            { "mro", "\u13b9\u13c8\u13d4\u13c2\u13a0 \u13a0\u13d5\u13b3 (1973\u20132017)" },
+            { "mru", "\u13b9\u13c8\u13d4\u13c2\u13a0 \u13a0\u13d5\u13b3" },
             { "mur", "\u13b9\u13d8\u13a2\u13ef \u13a0\u13d5\u13b3" },
             { "mvr", "\u13b9\u13b5\u13d7\u13eb\u13cd \u13a0\u13d5\u13b3" },
             { "mwk", "\u13b9\u13b3\u13eb \u13a0\u13d5\u13b3" },
@@ -337,7 +202,7 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
             { "srd", "\u13d2\u13b5\u13be\u13bb \u13a0\u13d5\u13b3" },
             { "ssp", "\u13e7\u13a6\u13be\u13ee \u13d1\u13d5\u13c2 \u13a0\u13d5\u13b3" },
             { "std", "\u13cc\u13a3\u13d9\u13ba \u13a0\u13b4 \u13c8\u13c2\u13cf\u13c7 \u13a0\u13d5\u13b3 (1977\u20132017)" },
-            { "stn", "\u13cc\u13a3\u13d9\u13ba \u13a0\u13b4 \u13c8\u13c2\u13cf\u13c7 \u13a0\u13d5\u13b3" },
+            { "stn", "\u13cc\u13a3\u13d9\u13ba & \u13c8\u13c2\u13cf\u13c7 \u13a0\u13d5\u13b3" },
             { "syp", "\u13cf\u13b5\u13a0 \u13a0\u13d5\u13b3" },
             { "szl", "\u13cd\u13e9\u13cf \u13a0\u13d5\u13b3" },
             { "thb", "\u13d4\u13ef\u13b4\u13c2 \u13a0\u13d5\u13b3" },
@@ -346,7 +211,7 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
             { "tnd", "\u13da\u13c2\u13cf\u13cd\u13a0 \u13a0\u13d5\u13b3" },
             { "top", "\u13d4\u13c2\u13aa \u13a0\u13d5\u13b3" },
             { "try", "\u13ac\u13c3 \u13a0\u13d5\u13b3" },
-            { "ttd", "\u13df\u13c2\u13d5\u13d7 \u13a0\u13b4 \u13d9\u13c6\u13aa \u13a0\u13d5\u13b3" },
+            { "ttd", "\u13df\u13c2\u13d5\u13d7 & \u13d9\u13c6\u13aa \u13a0\u13d5\u13b3" },
             { "twd", "\u13a2\u13e4 \u13d4\u13a2\u13e9\u13c2 \u13a0\u13d5\u13b3" },
             { "tzs", "\u13d6\u13c2\u13cf\u13c2\u13ef \u13a0\u13d5\u13b3" },
             { "uah", "\u13f3\u13a7\u13b4\u13c2 \u13a0\u13d5\u13b3" },
@@ -354,7 +219,8 @@ public class CurrencyNames_chr extends OpenListResourceBundle {
             { "usd", "US \u13a0\u13d5\u13b3" },
             { "uyu", "\u13f3\u13b7\u13c7 \u13a0\u13d5\u13b3" },
             { "uzs", "\u13a4\u13cd\u13c7\u13a9\u13cd\u13d6\u13c2 \u13a0\u13d5\u13b3" },
-            { "vef", "\u13ea\u13c1\u13d1\u13ea\u13b3 \u13a0\u13d5\u13b3" },
+            { "vef", "\u13ea\u13c1\u13d1\u13ea \u13a0\u13d5\u13b3 (2008\u20132018)" },
+            { "ves", "\u13ea\u13c1\u13d1\u13ea \u13a0\u13d5\u13b3" },
             { "vnd", "\u13eb\u13a1\u13d8\u13be\u13bb\u13cd \u13a0\u13d5\u13b3" },
             { "vuv", "\u13e9\u13c2\u13a4\u13e9\u13da \u13a0\u13d5\u13b3" },
             { "wst", "\u13cc\u13bc\u13a0 \u13a0\u13d5\u13b3" },
