@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -252,7 +252,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "MF", "Sv\u00e4t\u00fd Martin (fr.)" },
             { "MG", "Madagaskar" },
             { "MH", "Marshallove ostrovy" },
-            { "MK", "Maced\u00f3nsko" },
+            { "MK", "Severn\u00e9 Maced\u00f3nsko" },
             { "ML", "Mali" },
             { "MM", "Mjanmarsko" },
             { "MN", "Mongolsko" },
@@ -474,13 +474,13 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "my", "barm\u010dina" },
             { "na", "nauru\u0161tina" },
             { "nb", "n\u00f3r\u010dina (bokmal)" },
-            { "nd", "severn\u00e1 ndebel\u010dina" },
+            { "nd", "ndebel\u010dina (severn\u00e1)" },
             { "ne", "nep\u00e1l\u010dina" },
             { "ng", "ndonga" },
             { "nl", "holand\u010dina" },
             { "nn", "n\u00f3r\u010dina (nynorsk)" },
             { "no", "n\u00f3r\u010dina" },
-            { "nr", "ju\u017en\u00e1 ndebel\u010dina" },
+            { "nr", "ndebel\u010dina (ju\u017en\u00e1)" },
             { "nv", "navaho" },
             { "ny", "\u0148and\u017ea" },
             { "oc", "okcit\u00e1n\u010dina" },
@@ -502,7 +502,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "sa", "sanskrit" },
             { "sc", "sard\u00edn\u010dina" },
             { "sd", "sindh\u010dina" },
-            { "se", "severn\u00e1 saam\u010dina" },
+            { "se", "saam\u010dina (severn\u00e1)" },
             { "sg", "sango" },
             { "sh", "srbochorv\u00e1t\u010dina" },
             { "si", "sinhal\u010dina" },
@@ -514,7 +514,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "sq", "alb\u00e1n\u010dina" },
             { "sr", "srb\u010dina" },
             { "ss", "svazij\u010dina" },
-            { "st", "ju\u017en\u00e1 soth\u010dina" },
+            { "st", "soth\u010dina (ju\u017en\u00e1)" },
             { "su", "sund\u010dina" },
             { "sv", "\u0161v\u00e9d\u010dina" },
             { "sw", "swahil\u010dina" },
@@ -562,7 +562,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "arc", "aramej\u010dina" },
             { "arn", "mapudungun" },
             { "arp", "arapa\u017e\u0161tina" },
-            { "ars", "arab\u010dina \u2013 nad\u017ed" },
+            { "ars", "arab\u010dina (nad\u017edsk\u00e1)" },
             { "arw", "arawa\u010dtina" },
             { "asa", "asu" },
             { "ast", "ast\u00far\u010dina" },
@@ -761,7 +761,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "nog", "nogaj\u010dina" },
             { "non", "star\u00e1 n\u00f3r\u010dina" },
             { "nqo", "n\u2019ko" },
-            { "nso", "severn\u00e1 soth\u010dina" },
+            { "nso", "soth\u010dina (severn\u00e1)" },
             { "nus", "nuer" },
             { "nwc", "klasick\u00e1 nev\u00e1r\u010dina" },
             { "nym", "\u0148amwezi" },
@@ -809,10 +809,10 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "shn", "\u0161an\u010dina" },
             { "shu", "\u010dadsk\u00e1 arab\u010dina" },
             { "sid", "sidamo" },
-            { "sma", "ju\u017en\u00e1 saam\u010dina" },
-            { "smj", "lulsk\u00e1 saam\u010dina" },
-            { "smn", "inarijsk\u00e1 saam\u010dina" },
-            { "sms", "skoltsk\u00e1 saam\u010dina" },
+            { "sma", "saam\u010dina (ju\u017en\u00e1)" },
+            { "smj", "saam\u010dina (lulsk\u00e1)" },
+            { "smn", "saam\u010dina (inarijsk\u00e1)" },
+            { "sms", "saam\u010dina (skoltsk\u00e1)" },
             { "snk", "soninke" },
             { "sog", "sogdij\u010dina" },
             { "srn", "surinam\u010dina" },
@@ -842,7 +842,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "tvl", "tuval\u010dina" },
             { "twq", "tasawaq" },
             { "tyv", "tuvian\u010dina" },
-            { "tzm", "stredomarock\u00e1 tuareg\u010dina" },
+            { "tzm", "tuareg\u010dina (stredomarock\u00e1)" },
             { "udm", "udmurt\u010dina" },
             { "uga", "ugarit\u010dina" },
             { "umb", "umbundu" },
