@@ -253,7 +253,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "MH", "\u02bbOtumotu M\u0101solo" },
             { "MK", "Maset\u014dnia" },
             { "ML", "M\u0101li" },
-            { "MM", "Pema" },
+            { "MM", "Mianim\u0101 (Pema)" },
             { "MN", "Mongok\u014dlia" },
             { "MO", "Makau SAR Siaina" },
             { "MP", "\u02bbOtumotu Maliana tokelau" },
