@@ -166,14 +166,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "hora de Europa oriental",
                "\u2205\u2205\u2205",
             };
-        final String[] Argentina_Western = new String[] {
-               "hora est\u00e1ndar de Argentina occidental",
-               "",
-               "hora de verano de Argentina occidental",
-               "",
-               "hora de Argentina occidental",
-               "",
-            };
         final String[] Atlantic = new String[] {
                "hora est\u00e1ndar del Atl\u00e1ntico",
                "AST",
@@ -262,22 +254,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "hora de Apia",
                "",
             };
-        final String[] Myanmar = new String[] {
-               "hora de Myanmar (Birmania)",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Pyongyang = new String[] {
-               "hora de Pyongyang",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
             { "America/Denver", America_Mountain },
@@ -298,7 +274,16 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC",
                 new String[] {
@@ -314,9 +299,18 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "Pacific/Kwajalein", Marshall_Islands },
             { "America/El_Salvador", America_Central },
             { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
             { "America/Coral_Harbour", America_Eastern },
             { "Pacific/Marquesas", Marquesas },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Africa/Cairo", Europe_Eastern },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
@@ -332,7 +326,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Ojinaga", America_Mountain },
             { "America/Tegucigalpa", America_Central },
             { "Asia/Damascus", Europe_Eastern },
-            { "America/Argentina/San_Luis", Argentina_Western },
             { "Europe/Zaporozhye", Europe_Eastern },
             { "timezone.excity.Asia/Dushanbe", "Dusamb\u00e9" },
             { "Atlantic/Madeira", Europe_Western },
@@ -384,19 +377,10 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Menominee", America_Central },
             { "America/Adak", Hawaii_Aleutian },
             { "Pacific/Norfolk", Norfolk },
-            { "HST",
-                new String[] {
-                    "hora est\u00e1ndar de Haw\u00e1i-Aleutianas",
-                    "HST",
-                    "hora de verano de Haw\u00e1i-Aleutianas",
-                    "HDT",
-                    "hora de Haw\u00e1i-Aleutianas",
-                    "HST",
-                }
-            },
             { "America/Resolute", America_Central },
             { "Pacific/Tarawa", Gilbert_Islands },
             { "timezone.excity.Europe/Kirov", "Kirov" },
+            { "timezone.excity.America/Nassau", "Nassau" },
             { "SystemV/EST5", America_Eastern },
             { "America/Edmonton", America_Mountain },
             { "America/Santo_Domingo", Atlantic },
@@ -478,14 +462,13 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Swift_Current", America_Central },
             { "America/Metlakatla", Alaska },
             { "America/Pangnirtung", America_Eastern },
-            { "EST", America_Eastern },
             { "Europe/Sofia", Europe_Eastern },
-            { "MST", America_Mountain },
             { "America/Indiana/Vincennes", America_Eastern },
             { "America/Whitehorse", America_Pacific },
             { "America/Kralendijk", Atlantic },
             { "America/Antigua", Atlantic },
             { "America/Montreal", America_Eastern },
+            { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Antarctica/Macquarie", Macquarie },
@@ -493,7 +476,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Indiana/Winamac", America_Eastern },
             { "SystemV/MST7MDT", America_Mountain },
-            { "Asia/Pyongyang", Pyongyang },
             { "America/St_Vincent", Atlantic },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Acra" },
@@ -510,7 +492,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Asia/Rangoon", Myanmar },
             { "America/Yakutat", Alaska },
             { "Indian/Cocos", Cocos },
             { "SystemV/YST9YDT", Alaska },
@@ -544,8 +525,8 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                 }
             },
             { "America/Boise", America_Mountain },
-            { "America/North_Dakota/New_Salem", America_Central },
             { "EST5EDT", America_Eastern },
+            { "America/North_Dakota/New_Salem", America_Central },
             { "Pacific/Guam", Chamorro },
             { "Pacific/Wake", Wake },
             { "Atlantic/Bermuda", Atlantic },
